count property
double
get
count
Access the count of elements in a summary without labels.
Implementation
double get count => _noLabelChild.count;
Access the count of elements in a summary without labels.
double get count => _noLabelChild.count;